-- Filename: main.lua
-- Author: Peter Dijkstra

-- Requires
require "lib/middleclass.lua" --MiddleClass
HardonCollider = require "lib/HardonCollider" --Collision detection

--Scripts

require "scripts/Player.lua"
require "scripts/Projectile.lua"


-- Initialization
function love.load()
	
	-- Debug controls
	activateDebug = true -- true = debug on, false = debug off.

	lineNum       = 0 -- The line number for trace(). No need to change this!
	showColBox    = false -- true = visible colBoxes, false = invisble. Toggled with key 1.
	showDebugText = false -- true = visible overlay text, false = invisble. Toggled with key 2.
	
	-- Activate HardonCollider
	Collider = HardonCollider(128, on_collide, not_collide)
	
	-- Set up Imaget
	font = love.graphics.newImageFont("img/imagefont.png",
	    " abcdefghijklmnopqrstuvwxyz" ..
	    "ABCDEFGHIJKLMNOPQRSTUVWXYZ0" ..
	    "123456789.,!?-+/():;%&`'*#=[]\"")
	love.graphics.setFont(font)
	
	-- gameWidth and gameHeight are easier than long code!
	gameWidth  = love.graphics.getWidth()
	gameHeight = love.graphics.getHeight()

	playerOne = Player:new(1)
	playerOne:initialize()

	playerTwo = Player:new(2)
	playerTwo:initialize()

end

-- Logic
function love.update(dt)
	
	-- Update HardonCollider
	Collider:update(dt)

	-- Get FPS
	fps = love.timer.getFPS()

	playerOne:update(dt)
	playerTwo:update(dt)
	
end

-- Rendering
function love.draw()
	
	-- White background is better
	love.graphics.setBackgroundColor(255, 255, 255)
	
	-- Onscreen debug text
	if showDebugText == true then
		love.graphics.setColor(255,255,255)
		love.graphics.print("playerOne.energy = " .. playerOne.energy, 10, 10)
		love.graphics.print("playerTwo.energy = " .. playerTwo.energy, 10, 30)
		love.graphics.print("", 10, 50)
		-- Display FPS
		love.graphics.print(fps, gameWidth - 25, 10)
	end

	playerOne:draw()
	playerTwo:draw()
	
end

-- Key presses
function love.keypressed(key)
	
	-- Quit the game. !NOTE: This won't work in Löve2D 0.8!
	if key == "escape" then
		love.event.push("q")
	end
	
	if activateDebug == true then
		-- Show HardonCollider collision boxes
		if key == "1" then
			if showColBox == false then
				showColBox = true
				trace("cBox view activated")
			else
				showColBox = false
				trace("cBox view deactivated")
			end
		end
		
		-- Show overlay debug text
		if key == "2" then
			if showDebugText == false then
				showDebugText = true
				trace("Debug text view activated")
			else
				showDebugText = false
				trace("Debug text view deactivated")
			end
		end

		-- Enter interactive mode
		if key == "3" then
			debug.debug()
		end

	end
	
end

-- Easy use trace function, has line numbers and marking!
function trace(value, mark)
-- value = what you want to print(), mark = boolean, for easy searching in log

	-- prevent game from crashing if given value is nil
	if value == nil then
		value = "nil"
	end

	if activateDebug == true then

		lineNum = lineNum + 1

		local marked       = "[!" .. lineNum .. "!] " .. value
		local unmarked     = "[ " .. lineNum .. " ] " .. value

		if mark == true then
				print(marked)
			else 
				print(unmarked)
		end

	end

end